@@ -35,6 +35,9 @@ NativeWindowPair ApplicationContextSDL::createWindow(const Ogre::String& name, O
     NativeWindowPair ret = {NULL, NULL};
 
     if(!SDL_WasInit(SDL_INIT_VIDEO)) {
+        if(SDL_GameControllerAddMappingsFromFile("gamecontrollerdb.txt"))
+            Ogre::LogManager::getSingleton().logMessage("[SDL] gamecontrollerdb.txt loaded");
+
         SDL_InitSubSystem(SDL_INIT_VIDEO | SDL_INIT_GAMECONTROLLER);
     }
 
@@ -104,6 +107,16 @@ void ApplicationContextSDL::setWindowGrab(NativeWindowType* win, bool _grab)
 #endif
 }
 
+float ApplicationContextSDL::getDisplayDPI() const
+{
+    OgreAssert(!mWindows.empty(), "create a window first");
+    float vdpi = -1;
+    if(SDL_GetDisplayDPI(0, NULL, NULL, &vdpi) == 0 && vdpi > 0)
+        return vdpi;
+
+    return ApplicationContextBase::getDisplayDPI();
+}
+
 void ApplicationContextSDL::shutdown()
 {
     ApplicationContextBase::shutdown();
