@@ -28,6 +28,8 @@ Copyright (c) 2000-2014 Torus Knot Software Ltd
 #ifndef __GpuProgramParams_H_
 #define __GpuProgramParams_H_
 
+#include <limits>
+
 // Precompiler options
 #include "OgrePrerequisites.h"
 #include "OgreSharedPtr.h"
@@ -119,7 +121,7 @@ namespace Ogre {
     /** The variability of a GPU parameter, as derived from auto-params targeting it.
         These values must be powers of two since they are used in masks.
     */
-    enum GpuParamVariability
+    enum GpuParamVariability : uint16
     {
         /// No variation except by manual setting - the default
         GPV_GLOBAL = 1,
@@ -1049,7 +1051,7 @@ namespace Ogre {
             ACT_FAR_CLIP_DISTANCE,
 
             /** provides the pass index number within the technique
-                of the active materil.
+                of the active material.
             */
             ACT_PASS_NUMBER,
 
