@@ -204,7 +204,7 @@ namespace Ogre
         Used to confirm the settings (normally chosen by the user) in
         order to make the renderer able to initialise with the settings as required.
         This may initialise the @ref RenderWindowDescription or set some RenderSystem
-        specific paramters.
+        specific parameters.
         Called automatically by the default configuration
         dialog, and by the restoration of saved settings.
         These settings are stored and only activated when
@@ -380,13 +380,13 @@ namespace Ogre
         | title | String | RenderTarget name | The title of the window that will appear in the title bar |  |
         | left | Positive integers | Centred | Screen x coordinate from left |  |
         | top | Positive integers | Centred | Screen y coordinate from left |  |
-        | border | none, fixed, resize | resize | The type of window border (in windowed mode) |  |
         | hidden | true, false | false | hide the created window | |
         | FSAA | Positive integer (usually 0, 2, 4, 8, 16) | 0 | Full screen antialiasing factor |  |
         | gamma | true, false | false | Enable hardware conversion from linear colour space to gamma colour space on rendering to the window. |  |
         | vsync | true, false | false | Synchronize buffer swaps to monitor vsync, eliminating tearing at the expense of a fixed frame rate |  |
         | vsyncInterval | 1, 2, 3, 4 | 1 | If vsync is enabled, the minimum number of vertical blanks that should occur between renders. For example if vsync is enabled, the refresh rate is 60 and this is set to 2, then the frame rate will be locked at 30. |  |
         | Full Screen | true, false | false | Specify whether to create the window in full screen mode | |
+        | border | none, fixed, resize | resize | The type of window border (in windowed mode) | Windows, OSX |
         | displayFrequency | Refresh rate in Hertz (e.g. 60, 75, 100) | Desktop vsync rate | Display frequency rate, for fullscreen mode |  |
         | externalWindowHandle | <ul><li>Win32: HWND as int<li>Linux: X11 Window as ulong<li>OSX: OgreGLView address as an integer. You can pass NSView or NSWindow too, but should perform OgreGLView callbacks into the Ogre manually<li>iOS: UIWindow address as an integer<li>Emscripten: canvas selector String ("#canvas")</ul> | 0 (none) | External window handle, for embedding the OGRE render in an existing window |  |
         | externalGLControl | true, false | false | Let the external window control OpenGL i.e. don't select a pixel format for the window, do not change v-sync and do not swap buffer. When set to true, the calling application is responsible of OpenGL initialization and buffer swapping. It should also create an OpenGL context for its own rendering, Ogre will create one for its use. Then the calling application must also enable Ogre OpenGL context before calling any Ogre function and restore its OpenGL context after these calls. | OpenGL |
@@ -541,17 +541,8 @@ namespace Ogre
         virtual void _setTexture(size_t unit, bool enabled, 
             const TexturePtr &texPtr) = 0;
 
-        /** Binds a texture to a vertex, geometry, compute, tesselation hull
-        or tessellation domain sampler.
-        @remarks
-        Not all rendersystems support separate vertex samplers. For those that
-        do, you can set a texture for them, separate to the regular texture
-        samplers, using this method. For those that don't, you should use the
-        regular texture samplers which are shared between the vertex and
-        fragment units; calling this method will throw an exception.
-        @deprecated only needed for D3D9
-        */
-        virtual void _setVertexTexture(size_t unit, const TexturePtr& tex);
+        /// @deprecated obsolete
+        OGRE_DEPRECATED virtual void _setVertexTexture(size_t unit, const TexturePtr& tex);
 
         /**
         Sets the texture coordinate set to use for a texture unit.
@@ -690,15 +681,7 @@ namespace Ogre
         virtual Viewport* _getViewport(void);
 
         /** Sets the culling mode for the render system based on the 'vertex winding'.
-        A typical way for the rendering engine to cull triangles is based on the
-        'vertex winding' of triangles. Vertex winding refers to the direction in
-        which the vertices are passed or indexed to in the rendering operation as viewed
-        from the camera, and will wither be clockwise or anticlockwise (that's 'counterclockwise' for
-        you Americans out there ;) The default is CULL_CLOCKWISE i.e. that only triangles whose vertices
-        are passed/indexed in anticlockwise order are rendered - this is a common approach and is used in 3D studio models
-        for example. You can alter this culling mode if you wish but it is not advised unless you know what you are doing.
-        You may wish to use the CULL_NONE option for mesh data that you cull yourself where the vertex
-        winding is uncertain.
+        @copydetails Pass::setCullingMode
         */
         virtual void _setCullingMode(CullingMode mode) = 0;
 
@@ -808,9 +791,9 @@ namespace Ogre
         virtual void setStencilState(const StencilState& state) = 0;
 
         /// @deprecated use setStencilState
-        void setStencilCheckEnabled(bool enabled);
+        OGRE_DEPRECATED void setStencilCheckEnabled(bool enabled);
         /// @deprecated use setStencilState
-        void setStencilBufferParams(CompareFunction func = CMPF_ALWAYS_PASS, uint32 refValue = 0,
+        OGRE_DEPRECATED void setStencilBufferParams(CompareFunction func = CMPF_ALWAYS_PASS, uint32 refValue = 0,
                                     uint32 compareMask = 0xFFFFFFFF, uint32 writeMask = 0xFFFFFFFF,
                                     StencilOperation stencilFailOp = SOP_KEEP,
                                     StencilOperation depthFailOp = SOP_KEEP,
