@@ -73,7 +73,7 @@ namespace Ogre
             ~ 100 points per inch (probably 96 on Windows and 72 on Mac), that is independent
             of pixel density of real display, and are used through the all windowing system.
 
-            Sometimes, such view points are choosen bigger for output devices that are viewed
+            Sometimes, such view points are chosen bigger for output devices that are viewed
             from larger distances, like 30" TV comparing to 30" monitor, therefore maintaining
             constant points angular density rather than constant linear density.
 
@@ -186,7 +186,7 @@ namespace Ogre
 
         /** Indicates whether the window has been closed by the user.
         */
-        virtual bool isClosed(void) const = 0;
+        virtual bool isClosed(void) const { return mClosed; }
         
         /** Indicates whether the window is the primary window. The
             primary window is special in that it is destroyed when 
@@ -227,6 +227,7 @@ namespace Ogre
         bool mIsFullScreen;
         bool mIsPrimary;
         bool mAutoDeactivatedOnFocusChange;
+        bool mClosed;
         int mLeft;
         int mTop;
         unsigned int mVSyncInterval;
