@@ -36,22 +36,24 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     Camera::Camera( const String& name, SceneManager* sm)
         : Frustum(name),
-        mSceneMgr(sm),
+        mWindowSet(false),
+        mAutoAspectRatio(false),
+        mUseRenderingDistance(true),
+        mUseMinPixelSize(false),
+#ifdef OGRE_NODELESS_POSITIONING
         mOrientation(Quaternion::IDENTITY),
         mPosition(Vector3::ZERO),
-        mSceneDetail(PM_SOLID),
         mAutoTrackTarget(0),
         mAutoTrackOffset(Vector3::ZERO),
+#endif
         mSceneLodFactor(1.0f),
         mSceneLodFactorInv(1.0f),
-        mWindowSet(false),
         mLastViewport(0),
-        mAutoAspectRatio(false),
         mCullFrustum(0),
-        mUseRenderingDistance(true),
         mLodCamera(0),
-        mUseMinPixelSize(false),
-        mPixelDisplayRatio(0)
+        mPixelDisplayRatio(0),
+        mSortMode(SM_DISTANCE),
+        mSceneDetail(PM_SOLID)
     {
 
         // Reasonable defaults to camera params
@@ -61,8 +63,10 @@ namespace Ogre {
         mAspect = 1.33333333333333f;
         mProjType = PT_PERSPECTIVE;
 
+#ifdef OGRE_NODELESS_POSITIONING
         mYawFixed = true; // Default to fixed yaw, like freelook since most people expect this
         mYawFixedAxis = Vector3::UNIT_Y;
+#endif
 
         invalidateFrustum();
         invalidateView();
@@ -77,7 +81,7 @@ namespace Ogre {
         mReflect = false;
 
         mVisible = false;
-
+        mManager = sm;
     }
 
     //-----------------------------------------------------------------------
@@ -92,7 +96,7 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     SceneManager* Camera::getSceneManager(void) const
     {
-        return mSceneMgr;
+        return mManager;
     }
 
 
@@ -107,7 +111,7 @@ namespace Ogre {
     {
         return mSceneDetail;
     }
-
+#ifdef OGRE_NODELESS_POSITIONING
     //-----------------------------------------------------------------------
     void Camera::setPosition(Real x, Real y, Real z)
     {
@@ -150,7 +154,9 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void Camera::setDirection(Real x, Real y, Real z)
     {
+        OGRE_IGNORE_DEPRECATED_BEGIN
         setDirection(Vector3(x,y,z));
+        OGRE_IGNORE_DEPRECATED_END
     }
 
     //-----------------------------------------------------------------------
@@ -168,16 +174,9 @@ namespace Ogre {
 
         Quaternion targetWorldOrientation;
 
-
         if( mYawFixed )
         {
-            Vector3 xVec = mYawFixedAxis.crossProduct( zAdjustVec );
-            xVec.normalise();
-
-            Vector3 yVec = zAdjustVec.crossProduct( xVec );
-            yVec.normalise();
-
-            targetWorldOrientation.FromAxes( xVec, yVec, zAdjustVec );
+            targetWorldOrientation = Math::lookRotation(zAdjustVec, mYawFixedAxis);
         }
         else
         {
@@ -243,14 +242,18 @@ namespace Ogre {
     void Camera::lookAt(const Vector3& targetPoint)
     {
         updateView();
+        OGRE_IGNORE_DEPRECATED_BEGIN
         this->setDirection(targetPoint - mRealPosition);
+        OGRE_IGNORE_DEPRECATED_END
     }
 
     //-----------------------------------------------------------------------
     void Camera::lookAt( Real x, Real y, Real z )
     {
         Vector3 vTemp( x, y, z );
+        OGRE_IGNORE_DEPRECATED_BEGIN
         this->lookAt(vTemp);
+        OGRE_IGNORE_DEPRECATED_END
     }
 
     //-----------------------------------------------------------------------
@@ -258,7 +261,9 @@ namespace Ogre {
     {
         // Rotate around local Z axis
         Vector3 zAxis = mOrientation * Vector3::UNIT_Z;
+        OGRE_IGNORE_DEPRECATED_BEGIN
         rotate(zAxis, angle);
+        OGRE_IGNORE_DEPRECATED_END
 
         invalidateView();
     }
@@ -279,7 +284,9 @@ namespace Ogre {
             yAxis = mOrientation * Vector3::UNIT_Y;
         }
 
+        OGRE_IGNORE_DEPRECATED_BEGIN
         rotate(yAxis, angle);
+        OGRE_IGNORE_DEPRECATED_END
 
         invalidateView();
     }
@@ -289,7 +296,9 @@ namespace Ogre {
     {
         // Rotate around local X axis
         Vector3 xAxis = mOrientation * Vector3::UNIT_X;
+        OGRE_IGNORE_DEPRECATED_BEGIN
         rotate(xAxis, angle);
+        OGRE_IGNORE_DEPRECATED_END
 
         invalidateView();
 
@@ -300,7 +309,9 @@ namespace Ogre {
     {
         Quaternion q;
         q.FromAngleAxis(angle,axis);
+        OGRE_IGNORE_DEPRECATED_BEGIN
         rotate(q);
+        OGRE_IGNORE_DEPRECATED_END
     }
 
     //-----------------------------------------------------------------------
@@ -317,9 +328,67 @@ namespace Ogre {
 
     }
 
+    //-----------------------------------------------------------------------
+    void Camera::setFixedYawAxis(bool useFixed, const Vector3& fixedAxis)
+    {
+        mYawFixed = useFixed;
+        mYawFixedAxis = fixedAxis;
+    }
+    //-----------------------------------------------------------------------
+    const Quaternion& Camera::getOrientation(void) const
+    {
+        return mOrientation;
+    }
+    //-----------------------------------------------------------------------
+    void Camera::_autoTrack(void)
+    {
+        // NB assumes that all scene nodes have been updated
+        if (mAutoTrackTarget)
+        {
+            OGRE_IGNORE_DEPRECATED_BEGIN
+            lookAt(mAutoTrackTarget->_getFullTransform() * mAutoTrackOffset);
+            OGRE_IGNORE_DEPRECATED_END
+        }
+    }
+
+    //-----------------------------------------------------------------------
+    void Camera::setOrientation(const Quaternion& q)
+    {
+        mOrientation = q;
+        mOrientation.normalise();
+        invalidateView();
+    }
+    //-----------------------------------------------------------------------
+    void Camera::setAutoTracking(bool enabled, SceneNode* const target,
+        const Vector3& offset)
+    {
+        if (enabled)
+        {
+            assert (target != 0 && "target cannot be a null pointer if tracking is enabled");
+            mAutoTrackTarget = target;
+            mAutoTrackOffset = offset;
+        }
+        else
+        {
+            mAutoTrackTarget = 0;
+        }
+    }
+    //-----------------------------------------------------------------------
+    const Vector3& Camera::getPositionForViewUpdate(void) const
+    {
+        // Note no update, because we're calling this from the update!
+        return mRealPosition;
+    }
+    //-----------------------------------------------------------------------
+    const Quaternion& Camera::getOrientationForViewUpdate(void) const
+    {
+        return mRealOrientation;
+    }
+#endif
     //-----------------------------------------------------------------------
     bool Camera::isViewOutOfDate(void) const
     {
+#ifdef OGRE_NODELESS_POSITIONING
         // Overridden from Frustum to use local orientation / position offsets
         // Attached to node?
         if (mParentNode != 0)
@@ -354,16 +423,25 @@ namespace Ogre {
             mRecalcView = true;
             mRecalcWindow = true;
         }
+#else
+        if(Frustum::isViewOutOfDate())
+            mRecalcWindow = true;
+#endif
 
         // Deriving reflected orientation / position
         if (mRecalcView)
         {
+#ifndef OGRE_NODELESS_POSITIONING
+            const auto& mRealOrientation = mLastParentOrientation;
+            const auto& mRealPosition = mLastParentPosition;
+#endif
+
             if (mReflect)
             {
                 // Calculate reflected orientation, use up-vector as fallback axis.
-                Vector3 dir = mRealOrientation * Vector3::NEGATIVE_UNIT_Z;
+                Vector3 dir = -mRealOrientation.zAxis();
                 Vector3 rdir = dir.reflect(mReflectPlane.normal);
-                Vector3 up = mRealOrientation * Vector3::UNIT_Y;
+                Vector3 up = mRealOrientation.yAxis();
                 mDerivedOrientation = dir.getRotationTo(rdir, up) * mRealOrientation;
 
                 // Calculate reflected position.
@@ -393,7 +471,7 @@ namespace Ogre {
         Frustum::invalidateFrustum();
     }
     //-----------------------------------------------------------------------
-    void Camera::_renderScene(Viewport *vp, bool includeOverlays)
+    void Camera::_renderScene(Viewport *vp)
     {
         OgreProfileBeginGPUEvent(getName());
 
@@ -415,7 +493,7 @@ namespace Ogre {
         }
 
         //render scene
-        mSceneMgr->_renderScene(this, vp, includeOverlays);
+        mManager->_renderScene(this, vp);
 
         // Listener list may have change
         listenersCopy = mListeners;
@@ -443,9 +521,13 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     std::ostream& operator<<( std::ostream& o, const Camera& c )
     {
-        o << "Camera(Name='" << c.mName << "', pos=" << c.mPosition;
-        Vector3 dir(c.mOrientation*Vector3(0,0,-1));
-        o << ", direction=" << dir << ",near=" << c.mNearDist;
+        o << "Camera(Name='" << c.mName << "'";
+#ifdef OGRE_NODELESS_POSITIONING
+        o << ", pos=" << c.mPosition << ", direction=" << -c.mOrientation.zAxis();
+#else
+        o << ", pos=" << c.mLastParentPosition << ", direction=" << -c.mLastParentOrientation.zAxis();
+#endif
+        o << ",near=" << c.mNearDist;
         o << ", far=" << c.mFarDist << ", FOVy=" << c.mFOVy.valueDegrees();
         o << ", aspect=" << c.mAspect << ", ";
         o << ", xoffset=" << c.mFrustumOffset.x << ", yoffset=" << c.mFrustumOffset.y;
@@ -460,14 +542,6 @@ namespace Ogre {
 
         return o;
     }
-
-    //-----------------------------------------------------------------------
-    void Camera::setFixedYawAxis(bool useFixed, const Vector3& fixedAxis)
-    {
-        mYawFixed = useFixed;
-        mYawFixedAxis = fixedAxis;
-    }
-
     //-----------------------------------------------------------------------
     void Camera::_notifyRenderedFaces(unsigned int numfaces)
     {
@@ -491,19 +565,6 @@ namespace Ogre {
         return mVisBatchesLastRender;
     }
     //-----------------------------------------------------------------------
-    const Quaternion& Camera::getOrientation(void) const
-    {
-        return mOrientation;
-    }
-
-    //-----------------------------------------------------------------------
-    void Camera::setOrientation(const Quaternion& q)
-    {
-        mOrientation = q;
-        mOrientation.normalise();
-        invalidateView();
-    }
-    //-----------------------------------------------------------------------
     const Quaternion& Camera::getDerivedOrientation(void) const
     {
         updateView();
@@ -520,64 +581,70 @@ namespace Ogre {
     {
         // Direction points down -Z
         updateView();
-        return mDerivedOrientation * Vector3::NEGATIVE_UNIT_Z;
+        return -mDerivedOrientation.zAxis();
     }
     //-----------------------------------------------------------------------
     Vector3 Camera::getDerivedUp(void) const
     {
         updateView();
-        return mDerivedOrientation * Vector3::UNIT_Y;
+        return mDerivedOrientation.yAxis();
     }
     //-----------------------------------------------------------------------
     Vector3 Camera::getDerivedRight(void) const
     {
         updateView();
-        return mDerivedOrientation * Vector3::UNIT_X;
+        return mDerivedOrientation.xAxis();
     }
     //-----------------------------------------------------------------------
     const Quaternion& Camera::getRealOrientation(void) const
     {
         updateView();
+#ifdef OGRE_NODELESS_POSITIONING
         return mRealOrientation;
+#else
+        return mLastParentOrientation;
+#endif
     }
     //-----------------------------------------------------------------------
     const Vector3& Camera::getRealPosition(void) const
     {
         updateView();
+#ifdef OGRE_NODELESS_POSITIONING
         return mRealPosition;
+#else
+        return mLastParentPosition;
+#endif
     }
     //-----------------------------------------------------------------------
     Vector3 Camera::getRealDirection(void) const
     {
         // Direction points down -Z
         updateView();
+#ifdef OGRE_NODELESS_POSITIONING
         return mRealOrientation * Vector3::NEGATIVE_UNIT_Z;
+#else
+        return -mLastParentOrientation.zAxis();
+#endif
     }
     //-----------------------------------------------------------------------
     Vector3 Camera::getRealUp(void) const
     {
         updateView();
+#ifdef OGRE_NODELESS_POSITIONING
         return mRealOrientation * Vector3::UNIT_Y;
+#else
+        return mLastParentOrientation.yAxis();
+#endif
     }
     //-----------------------------------------------------------------------
     Vector3 Camera::getRealRight(void) const
     {
         updateView();
+#ifdef OGRE_NODELESS_POSITIONING
         return mRealOrientation * Vector3::UNIT_X;
-    }
-    //-----------------------------------------------------------------------
-    void Camera::getWorldTransforms(Matrix4* mat) const 
-    {
-        updateView();
-
-        Vector3 scale(1.0, 1.0, 1.0);
-        if (mParentNode)
-          scale = mParentNode->_getDerivedScale();
-
-        mat->makeTransform(
-                mDerivedPosition,
-                scale,
-                mDerivedOrientation);
+#else
+        return mLastParentOrientation.xAxis();
+#endif
     }
     //-----------------------------------------------------------------------
     const String& Camera::getMovableType(void) const
@@ -585,30 +652,6 @@ namespace Ogre {
         return msMovableType;
     }
     //-----------------------------------------------------------------------
-    void Camera::setAutoTracking(bool enabled, SceneNode* const target, 
-        const Vector3& offset)
-    {
-        if (enabled)
-        {
-            assert (target != 0 && "target cannot be a null pointer if tracking is enabled");
-            mAutoTrackTarget = target;
-            mAutoTrackOffset = offset;
-        }
-        else
-        {
-            mAutoTrackTarget = 0;
-        }
-    }
-    //-----------------------------------------------------------------------
-    void Camera::_autoTrack(void)
-    {
-        // NB assumes that all scene nodes have been updated
-        if (mAutoTrackTarget)
-        {
-            lookAt(mAutoTrackTarget->_getFullTransform() * mAutoTrackOffset);
-        }
-    }
-    //-----------------------------------------------------------------------
     void Camera::setLodBias(Real factor)
     {
         assert(factor > 0.0f && "Bias factor must be > 0!");
@@ -839,17 +882,6 @@ namespace Ogre {
 
     }
     //-----------------------------------------------------------------------
-    const Vector3& Camera::getPositionForViewUpdate(void) const
-    {
-        // Note no update, because we're calling this from the update!
-        return mRealPosition;
-    }
-    //-----------------------------------------------------------------------
-    const Quaternion& Camera::getOrientationForViewUpdate(void) const
-    {
-        return mRealOrientation;
-    }
-    //-----------------------------------------------------------------------
     bool Camera::getAutoAspectRatio(void) const
     {
         return mAutoAspectRatio;
@@ -896,7 +928,7 @@ namespace Ogre {
         }
     }
     //-----------------------------------------------------------------------
-    const Vector3* Camera::getWorldSpaceCorners(void) const
+    const Frustum::Corners& Camera::getWorldSpaceCorners(void) const
     {
         if (mCullFrustum)
         {
@@ -1121,9 +1153,11 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void Camera::synchroniseBaseSettingsWith(const Camera* cam)
     {
-        mPosition = cam->mPosition;
         this->setProjectionType(cam->getProjectionType());
+#ifdef OGRE_NODELESS_POSITIONING
+        mPosition = cam->mPosition;
         mOrientation = cam->mOrientation;
+#endif
         invalidateView();
         this->setAspectRatio(cam->getAspectRatio());
         this->setNearClipDistance(cam->getNearClipDistance());
