@@ -126,7 +126,7 @@ void SceneManager::ShadowRenderer::renderAdditiveStencilShadowedQueueGroupObject
     RenderQueueGroup* pGroup,
     QueuedRenderableCollection::OrganisationMode om)
 {
-    LightList lightList;
+    LightList lightList(1);
     auto visitor = mSceneManager->getQueuedRenderableVisitor();
 
     for (const auto& pg : pGroup->getPriorityGroups())
@@ -136,11 +136,8 @@ void SceneManager::ShadowRenderer::renderAdditiveStencilShadowedQueueGroupObject
         // Sort the queue first
         pPriorityGrp->sort(mSceneManager->mCameraInProgress);
 
-        // Clear light list
-        lightList.clear();
-
         // Render all the ambient passes first, no light iteration, no lights
-        visitor->renderObjects(pPriorityGrp->getSolidsBasic(), om, false, false, &lightList);
+        visitor->renderObjects(pPriorityGrp->getSolidsBasic(), om, false, false);
         // Also render any objects which have receive shadows disabled
         visitor->renderObjects(pPriorityGrp->getSolidsNoShadowReceive(), om, true, true);
 
@@ -150,10 +147,7 @@ void SceneManager::ShadowRenderer::renderAdditiveStencilShadowedQueueGroupObject
         for (Light* l : mSceneManager->_getLightsAffectingFrustum())
         {
             // Set light state
-            if (lightList.empty())
-                lightList.push_back(l);
-            else
-                lightList[0] = l;
+            lightList[0] = l;
 
             // set up scissor, will cover shadow vol and regular light rendering
             ClipResult scissored = mSceneManager->buildAndSetScissor(lightList, mSceneManager->mCameraInProgress);
@@ -326,13 +320,13 @@ void SceneManager::ShadowRenderer::renderTextureShadowCasterQueueGroupObjects(
         pPriorityGrp->sort(mSceneManager->mCameraInProgress);
 
         // Do solids, override light list incase any vertex programs use them
-        visitor->renderObjects(pPriorityGrp->getSolidsBasic(), om, false, false, &mShadowTextureCurrentCasterLightList);
-        visitor->renderObjects(pPriorityGrp->getSolidsNoShadowReceive(), om, false, false, &mShadowTextureCurrentCasterLightList);
+        visitor->renderObjects(pPriorityGrp->getSolidsBasic(), om, false, false);
+        visitor->renderObjects(pPriorityGrp->getSolidsNoShadowReceive(), om, false, false);
         // Do unsorted transparents that cast shadows
-        visitor->renderObjects(pPriorityGrp->getTransparentsUnsorted(), om, false, false, &mShadowTextureCurrentCasterLightList);
+        visitor->renderObjects(pPriorityGrp->getTransparentsUnsorted(), om, false, false, nullptr, true);
         // Do transparents that cast shadows
-        visitor->renderObjects(pPriorityGrp->getTransparents(), QueuedRenderableCollection::OM_SORT_DESCENDING,
-                      false, false, &mShadowTextureCurrentCasterLightList, true);
+        visitor->renderObjects(pPriorityGrp->getTransparents(), QueuedRenderableCollection::OM_SORT_DESCENDING, false,
+                               false, nullptr, true);
 
     }// for each priority
 
@@ -482,7 +476,7 @@ void SceneManager::ShadowRenderer::renderAdditiveTextureShadowedQueueGroupObject
     RenderQueueGroup* pGroup,
     QueuedRenderableCollection::OrganisationMode om)
 {
-    LightList lightList;
+    LightList lightList(1);
     auto visitor = mSceneManager->getQueuedRenderableVisitor();
 
     for (const auto& pg : pGroup->getPriorityGroups())
@@ -492,11 +486,8 @@ void SceneManager::ShadowRenderer::renderAdditiveTextureShadowedQueueGroupObject
         // Sort the queue first
         pPriorityGrp->sort(mSceneManager->mCameraInProgress);
 
-        // Clear light list
-        lightList.clear();
-
         // Render all the ambient passes first, no light iteration, no lights
-        visitor->renderObjects(pPriorityGrp->getSolidsBasic(), om, false, false, &lightList);
+        visitor->renderObjects(pPriorityGrp->getSolidsBasic(), om, false, false);
         // Also render any objects which have receive shadows disabled
         visitor->renderObjects(pPriorityGrp->getSolidsNoShadowReceive(), om, true, true);
 
@@ -552,10 +543,7 @@ void SceneManager::ShadowRenderer::renderAdditiveTextureShadowedQueueGroupObject
                 }
 
                 // render lighting passes for this light
-                if (lightList.empty())
-                    lightList.push_back(l);
-                else
-                    lightList[0] = l;
+                lightList[0] = l;
 
                 // set up light scissoring, always useful in additive modes
                 ClipResult scissored = mSceneManager->buildAndSetScissor(lightList, mSceneManager->mCameraInProgress);
@@ -603,8 +591,6 @@ void SceneManager::ShadowRenderer::renderTextureShadowReceiverQueueGroupObjects(
     RenderQueueGroup* pGroup,
     QueuedRenderableCollection::OrganisationMode om)
 {
-    static LightList nullLightList;
-
     // Iterate through priorities
 
     // Override auto param ambient to force vertex programs to go full-bright
@@ -617,7 +603,7 @@ void SceneManager::ShadowRenderer::renderTextureShadowReceiverQueueGroupObjects(
         RenderPriorityGroup* pPriorityGrp = pg.second;
 
         // Do solids, override light list incase any vertex programs use them
-        visitor->renderObjects(pPriorityGrp->getSolidsBasic(), om, false, false, &nullLightList);
+        visitor->renderObjects(pPriorityGrp->getSolidsBasic(), om, false, false);
 
         // Don't render transparents or passes which have shadow receipt disabled
 
@@ -818,11 +804,6 @@ void SceneManager::ShadowRenderer::prepareShadowTextures(Camera* cam, Viewport*
         if (!light->getCastShadows())
             continue;
 
-        if (mShadowTextureCurrentCasterLightList.empty())
-            mShadowTextureCurrentCasterLightList.push_back(light);
-        else
-            mShadowTextureCurrentCasterLightList[0] = light;
-
         // texture iteration per light.
         size_t textureCountPerLight = mShadowTextureCountPerType[light->getType()];
         for (size_t j = 0; j < textureCountPerLight && si != siend; ++j)
@@ -1317,6 +1298,8 @@ void SceneManager::ShadowRenderer::setShadowTechnique(ShadowTechnique technique)
         }
     }
 
+    if(mShadowTechnique)
+        initShadowVolumeMaterials();
 }
 //---------------------------------------------------------------------
 void SceneManager::ShadowRenderer::initShadowVolumeMaterials()
@@ -1495,8 +1478,6 @@ const Pass* SceneManager::ShadowRenderer::deriveShadowReceiverPass(const Pass* p
             retPass->setDiffuse(pass->getDiffuse());
             retPass->setSpecular(pass->getSpecular());
             retPass->setShininess(pass->getShininess());
-            retPass->setIteratePerLight(pass->getIteratePerLight(),
-                pass->getRunOnlyForOneLightType(), pass->getOnlyLightType());
             retPass->setLightMask(pass->getLightMask());
 
             // We need to keep alpha rejection settings
@@ -1530,6 +1511,10 @@ const Pass* SceneManager::ShadowRenderer::deriveShadowReceiverPass(const Pass* p
             keepTUCount = retPass->getNumTextureUnitStates();
         }
 
+        // re-/set light iteration settings
+        retPass->setIteratePerLight(pass->getIteratePerLight(), pass->getRunOnlyForOneLightType(),
+                                    pass->getOnlyLightType());
+
         // Remove any extra texture units
         while (retPass->getNumTextureUnitStates() > keepTUCount)
         {
