@@ -98,9 +98,6 @@ namespace Ogre {
         OGRE_CHECK_GL_ERROR(glGenTextures(1, &mTextureID));
         GLenum texTarget = getGL3PlusTextureTarget();
 
-        if (mRenderSystem->getCapabilities()->hasCapability(RSC_DEBUG))
-            OGRE_CHECK_GL_ERROR(glObjectLabel(GL_TEXTURE, mTextureID, -1, mName.c_str()));
-
         // Calculate size for all mip levels of the texture.
         uint32 width, height, depth;
 
@@ -113,6 +110,9 @@ namespace Ogre {
         // for that type.
         mRenderSystem->_getStateCacheManager()->bindGLTexture( texTarget, mTextureID );
 
+        if (mRenderSystem->getCapabilities()->hasCapability(RSC_DEBUG))
+            OGRE_CHECK_GL_ERROR(glObjectLabel(GL_TEXTURE, mTextureID, -1, mName.c_str()));
+
         mRenderSystem->_getStateCacheManager()->setTexParameteri(texTarget, GL_TEXTURE_BASE_LEVEL, 0);
         mRenderSystem->_getStateCacheManager()->setTexParameteri(texTarget, GL_TEXTURE_MAX_LEVEL, mNumMipmaps);
 
@@ -355,9 +355,8 @@ namespace Ogre {
 
             for (uint32 mip = 0; mip <= getNumMipmaps(); mip++)
             {
-                GL3PlusHardwarePixelBuffer* buf =
-                    new GL3PlusTextureBuffer(this, face, mip, width, height, depth);
-                mSurfaceList.push_back(HardwarePixelBufferSharedPtr(buf));
+                auto buf = std::make_shared<GL3PlusTextureBuffer>(this, face, mip, width, height, depth);
+                mSurfaceList.push_back(buf);
 
                 if (width > 1)
                     width = width / 2;
