@@ -265,7 +265,6 @@ namespace Ogre {
         {
             rsc->setCapability(RSC_HWSTENCIL);
             rsc->setCapability(RSC_TWO_SIDED_STENCIL);
-            rsc->setStencilBufferBitDepth(stencil);
         }
 
         if(hasMinGLVersion(3, 0) ||
@@ -353,9 +352,6 @@ namespace Ogre {
 
         // Stencil wrapping
         rsc->setCapability(RSC_STENCIL_WRAP);
-
-        // GL always shares vertex and fragment texture units (for now?)
-        rsc->setVertexTextureUnitsShared(true);
         
         // Point size
         GLfloat psRange[2] = {0.0, 0.0};
@@ -401,25 +397,13 @@ namespace Ogre {
         }
 
         GLfloat floatConstantCount = 0;
-#if OGRE_NO_GLES3_SUPPORT == 0
-        glGetFloatv(GL_MAX_VERTEX_UNIFORM_COMPONENTS, &floatConstantCount);
-#else
         glGetFloatv(GL_MAX_VERTEX_UNIFORM_VECTORS, &floatConstantCount);
-#endif
         rsc->setVertexProgramConstantFloatCount((Ogre::ushort)floatConstantCount);
-        rsc->setVertexProgramConstantBoolCount((Ogre::ushort)floatConstantCount);
-        rsc->setVertexProgramConstantIntCount((Ogre::ushort)floatConstantCount);
 
         // Fragment Program Properties
         floatConstantCount = 0;
-#if OGRE_NO_GLES3_SUPPORT == 0
-        glGetFloatv(GL_MAX_FRAGMENT_UNIFORM_COMPONENTS, &floatConstantCount);
-#else
         glGetFloatv(GL_MAX_FRAGMENT_UNIFORM_VECTORS, &floatConstantCount);
-#endif
         rsc->setFragmentProgramConstantFloatCount((Ogre::ushort)floatConstantCount);
-        rsc->setFragmentProgramConstantBoolCount((Ogre::ushort)floatConstantCount);
-        rsc->setFragmentProgramConstantIntCount((Ogre::ushort)floatConstantCount);
 
         // Check for Float textures
         if(hasMinGLVersion(3, 0) || checkExtension("GL_OES_texture_float") || checkExtension("GL_OES_texture_half_float"))
@@ -530,7 +514,6 @@ namespace Ogre {
         mHardwareBufferManager = OGRE_NEW GLES2HardwareBufferManager();
 
         // Create FBO manager
-        LogManager::getSingleton().logMessage("GL ES 2: Using FBOs for rendering to textures");
         mRTTManager = new GLES2FBOManager();
 
         mGLInitialised = true;
@@ -1208,16 +1191,12 @@ namespace Ogre {
 
         HardwareVertexBufferSharedPtr globalInstanceVertexBuffer;
         VertexDeclaration* globalVertexDeclaration = 0;
-        bool hasInstanceData = false;
+
         size_t numberOfInstances = 0;
         if(getCapabilities()->hasCapability(RSC_VERTEX_BUFFER_INSTANCE_DATA))
         {
             globalInstanceVertexBuffer = getGlobalInstanceVertexBuffer();
             globalVertexDeclaration = getGlobalInstanceVertexBufferVertexDeclaration();
-            hasInstanceData = (op.useGlobalInstancingVertexBufferIsAvailable &&
-                                globalInstanceVertexBuffer && (globalVertexDeclaration != NULL))
-                                || op.vertexData->vertexBufferBinding->hasInstanceData();
-
             numberOfInstances = op.numberOfInstances;
 
             if (op.useGlobalInstancingVertexBufferIsAvailable)
@@ -1296,7 +1275,7 @@ namespace Ogre {
 
             do
             {
-                if(hasInstanceData && getCapabilities()->hasCapability(RSC_VERTEX_BUFFER_INSTANCE_DATA))
+                if(numberOfInstances > 1)
                 {
                     OGRE_CHECK_GL_ERROR(glDrawElementsInstancedEXT((polyMode == GL_FILL) ? primType : polyMode, static_cast<GLsizei>(op.indexData->indexCount), indexType, pBufferData, static_cast<GLsizei>(numberOfInstances)));
                 }
@@ -1311,7 +1290,7 @@ namespace Ogre {
         {
             do
             {
-                if(getCapabilities()->hasCapability(RSC_VERTEX_BUFFER_INSTANCE_DATA) && hasInstanceData)
+                if(numberOfInstances > 1)
                 {
                     OGRE_CHECK_GL_ERROR(glDrawArraysInstancedEXT((polyMode == GL_FILL) ? primType : polyMode, 0, static_cast<GLsizei>(op.vertexData->vertexCount), static_cast<GLsizei>(numberOfInstances)));
                 }
