@@ -109,12 +109,12 @@ namespace Ogre {
         // Generate texture name
         OGRE_CHECK_GL_ERROR(glGenTextures(1, &mTextureID));
 
+        // Set texture type
+        mRenderSystem->_getStateCacheManager()->bindGLTexture(texTarget, mTextureID);
+
         if (renderCaps->hasCapability(RSC_DEBUG))
             OGRE_CHECK_GL_ERROR(glLabelObjectEXT(GL_TEXTURE, mTextureID, -1, mName.c_str()));
 
-        // Set texture type
-        mRenderSystem->_getStateCacheManager()->bindGLTexture(texTarget, mTextureID);
-        
         // If we can do automip generation and the user desires this, do so
         mMipmapsHardwareGenerated = !PixelUtil::isCompressed(mFormat);
 
@@ -404,10 +404,8 @@ namespace Ogre {
 
             for (uint32 mip = 0; mip <= getNumMipmaps(); mip++)
             {
-                GLES2HardwarePixelBuffer* buf = OGRE_NEW GLES2TextureBuffer(
-                    this, static_cast<GLint>(face), mip, width, height, depth);
-
-                mSurfaceList.push_back(HardwarePixelBufferSharedPtr(buf));
+                auto buf = std::make_shared<GLES2TextureBuffer>(this, int(face), mip, width, height, depth);
+                mSurfaceList.push_back(buf);
 
                 if (width > 1)
                     width = width / 2;
