@@ -469,7 +469,7 @@ namespace Ogre
             device->mGraphicsQueue.getCopyEncoder( 0, this, true );
         }
 
-        const uint32 numSlices = getDepth();
+        const uint32 numSlices = getNumLayers();
 
         VkImageMemoryBarrier imageBarrier = getImageMemoryBarrier();
 
@@ -616,6 +616,11 @@ namespace Ogre
                                           VK_COMPONENT_SWIZZLE_ONE};
             }
         }
+        else if (mFormat == PF_A8)
+        {
+            imageViewCi.components = {VK_COMPONENT_SWIZZLE_ONE, VK_COMPONENT_SWIZZLE_ONE, VK_COMPONENT_SWIZZLE_ONE,
+                                      VK_COMPONENT_SWIZZLE_R};
+        }
 
         // Using both depth & stencil aspects in an image view for texture sampling is illegal
         // Thus prefer depth over stencil. We only use both flags for FBOs
@@ -778,7 +783,7 @@ namespace Ogre
             mDepthTexture.reset(new VulkanTextureGpu(texMgr, mName+"/Depth", 0, "", true, 0));
             mDepthTexture->setWidth(target->getWidth());
             mDepthTexture->setHeight(target->getHeight());
-            mDepthTexture->setFormat(PF_DEPTH32F);
+            mDepthTexture->setFormat(PF_DEPTH24_STENCIL8);
             mDepthTexture->createInternalResources();
             mDepthTexture->setFSAA(1, "");
         }
